@@ -1,21 +1,14 @@
 #include "logindialog.h"
 
-LoginDialog::LoginDialog(Spotify::Session* pSession, QSettings* pSettings, QWidget *parent)
+LoginDialog::LoginDialog(QSettings* pSettings, QWidget *parent)
     : QDialog(parent)
 {
-
- //construct login dialog UI
-
-    m_pSession = pSession;
-
+    //construct login dialog UI
     m_pAppSettings = pSettings;
 
-    m_bSessionInit = false;
-
     //setup signal / slot connections
-
     connect(&m_LoginBtn,SIGNAL(clicked()),SLOT(OnLogin()));
-   //connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
+    //connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
 
     setWindowTitle(tr("QSpot - Login"));
 
@@ -36,14 +29,6 @@ LoginDialog::LoginDialog(Spotify::Session* pSession, QSettings* pSettings, QWidg
             m_UserIDInput.setText(m_pAppSettings->value("QSpot/UserID","").toString());
             m_PasswordInput.setText(m_pAppSettings->value("QSpot/Password","").toString());
         }
-        //read preferred bitrate from settings file
-        int prefBitrate = m_pAppSettings->value("QSpot/PrefBitrate",IDX_BITRATE_160k).toInt();
-        if(prefBitrate==IDX_BITRATE_96k)
-            m_selectedBitrate = SP_BITRATE_96k;
-        else if(prefBitrate==IDX_BITRATE_320k)
-            m_selectedBitrate = SP_BITRATE_320k;
-        else //default bitrate
-            m_selectedBitrate = SP_BITRATE_160k;
     }
 
     m_Layout.addWidget(&m_UserIDText,0,0);
@@ -64,33 +49,18 @@ LoginDialog::~LoginDialog()
 
 void LoginDialog::OnLogin()
 {
-    QMessageBox msgBox;
-
     //request to login to Spotify
-    if(!m_bSessionInit)
-    {
-        m_pSession->init(m_selectedBitrate); //init the spotify session (if not already done)
-        m_bSessionInit = true;
-    }
-    Spotify::Error err = m_pSession->login(m_UserIDInput.text(),m_PasswordInput.text());
-    if(err.isError())
-    {
-        msgBox.setText("Error:" + err.toString());
-        msgBox.exec();
-    }
-    else
-    {
-        m_LoginBtn.setDisabled(true);
 #ifdef Q_WS_MAEMO_5
-        setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+    setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
 #endif
-    }
+    m_LoginBtn.setDisabled(true);
+    emit doSpotifyLogin(m_UserIDInput.text(),m_PasswordInput.text());
 }
 
 
 void LoginDialog::resetState()
 {
-	//reset state after e.g., unsuccessful login
+        //reset state after e.g., login
 #ifdef Q_WS_MAEMO_5
 	setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
 #endif
@@ -100,7 +70,6 @@ void LoginDialog::resetState()
         //m_PasswordInput.setText("");
 	m_PasswordInput.setCursorPosition(0);
 	m_UserIDInput.setFocus();
-        m_bSessionInit = true; //make sure we do not re-initialise the session
 }
 
 void LoginDialog::OnOrientationChanged()
