@@ -12,7 +12,6 @@
 #include <QtGui/QComboBox>
 #include <QDebug>
 #include <QSettings>
-#include <qspotify_src/spotifysession.h>
 #include "global_defs.h"
 
 
@@ -21,7 +20,7 @@ class LoginDialog : public QDialog
     Q_OBJECT
 
 public:
-    LoginDialog(Spotify::Session* pSession, QSettings* pSettings, QWidget *parent = 0);
+    LoginDialog(QSettings* pSettings, QWidget *parent = 0);
     ~LoginDialog();
 
     void resetState();
@@ -30,9 +29,6 @@ private:
 
     QGridLayout m_Layout;
 
-    Spotify::Session* m_pSession; //pointer to Spotify session instance
-    sp_bitrate m_selectedBitrate; //prefered (selected) bitrate passed to the Spotify session instance
-
     QLabel m_UserIDText;
     QLineEdit m_UserIDInput;
     QLabel m_PasswordText;
@@ -42,13 +38,15 @@ private:
 
     QSettings* m_pAppSettings; //pointer to app settings instance
 
-    bool m_bSessionInit; //TRUE if session has been initialised
-
 private slots:
 
     void OnLogin();
     void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
 
+signals:
+
+    void doSpotifyLogin(const QString&, const QString&); //request to login
+
 };
 
 #endif // LOGINDIALOG_H
