@@ -12,15 +12,11 @@ MainWindow::MainWindow(QWidget *parent)
     QCoreApplication::setApplicationVersion(APP_VERSION); //Setup app version
 
     m_pAppSettings = new QSettings("qspot","qspot", this); //allocate application settings instance
-
     setupUILang(); //setup the UI language
-
     setWindowTitle(tr("QSpot - Playlists"));
 
     m_playing = false;
-
     m_update = false;
-
     m_reConnectReq = false;
 
     m_pSpectrum = new SpectrumAnalyzer(this,55,40);
@@ -60,12 +56,15 @@ MainWindow::MainWindow(QWidget *parent)
     m_pConnMan = new ConnectionManager(this); //allocate connection manager instance
     connect(m_pConnMan,SIGNAL(reconnectRequired()),SLOT(OnSpotifyReconnectRequired()));
 
-
-    m_pTimeoutTimer  = new QTimer(this); //timeout timer instance
+    m_pTimeoutTimer  = new QTimer(this); //allocate timeout timer instance
     connect(m_pTimeoutTimer,SIGNAL(timeout()),SLOT(OnPlaylistLoadingTimeout()));
+    m_pReconnectTimer = new QTimer(this); //allocate reconnect timer instance
+    connect(m_pReconnectTimer,SIGNAL(timeout()),SLOT(OnReconnectTimeout()));
 
-    m_pLoginDlg = new LoginDialog(m_pSession,m_pAppSettings, this); //allocate login dialog instance
+    m_pHelpViewer = new HelpViewer(this); //allocate online help instance
 
+    m_pLoginDlg = new LoginDialog(m_pAppSettings, this); //allocate login dialog instance
+    connect(m_pLoginDlg,SIGNAL(doSpotifyLogin(const QString&, const QString&)),SLOT(OnSpotifyLogin(const QString&, const QString&)));
     m_pSettingsDlg = new SettingsDialog(m_pAppSettings, this); //allocate settings dialog instance
 
     //set up the the main window menu
@@ -73,6 +72,7 @@ MainWindow::MainWindow(QWidget *parent)
 #ifdef Q_WS_MAEMO_5
     menuBar()->addAction(tr("FM Transmitter"));
 #endif
+    menuBar()->addAction(tr("Online Help"));
     menuBar()->addAction(tr("About"));
 
     //setup the app About dialog box
@@ -123,6 +123,7 @@ MainWindow::MainWindow(QWidget *parent)
     connect(m_pPlaylistView,SIGNAL(activated(QModelIndex)),SLOT(OnPlaylistActivated(QModelIndex)));
     connect(menuBar(),SIGNAL(triggered(QAction*)),SLOT(OnMainMenuAction(QAction*)));
     connect(this,SIGNAL(showLogin()),SLOT(OnShowLogin()),Qt::QueuedConnection);
+    connect(this,SIGNAL(handleLoginType()),SLOT(OnHandleLoginType()),Qt::QueuedConnection);
     connect(&m_NowPlayingIcon,SIGNAL(clicked()),SLOT(OnNowPlaying()));
     connect(&m_NowPlayingInfo,SIGNAL(clicked()), SLOT(OnNowPlaying()));
     connect(&m_NowPlayingPositionInfo,SIGNAL(clicked()), SLOT(OnNowPlaying()));
@@ -171,24 +172,21 @@ MainWindow::MainWindow(QWidget *parent)
     setCentralWidget(&m_MainLayout);
 
     m_AudioInit = false;
+    m_SessionInit = false;
 
     setDisplayOrientation(m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt()); //set initial display orientation for views / dialogs
 
-    handleSpotifyLogin(); //handle login process
+    emit handleLoginType(); //check whether we should login directly, or allow user to enter login credentials (display login dialog accordingly)
 }
 
-void MainWindow::handleSpotifyLogin()
+void MainWindow::OnSpotifyLogin(const QString& strUserID, const QString& strPassword)
 {
-   //Method for handling the login process to Spotify. Performs automatic-login in case user has specified that credentials should be saved;
-   //otherwise the login dialog is displayed.
-
-    QMessageBox msgBox;
+    //Sends of actual login req. to Spotify service backend. Inits app network session if necessary.
+    Spotify::Error err;
     sp_bitrate selectedBitrate;
 
-    if(m_pAppSettings->value("QSpot/SaveCredentials",SAVE_CREDENTIALS_DEFAULT).toInt())
-    {
-        //perform auto-login in case user has saved credentials
-
+    if(!m_SessionInit)
+    {//session not initialised; init session
         //read preferred bitrate from settings file
         int prefBitrate = m_pAppSettings->value("QSpot/PrefBitrate",IDX_BITRATE_160k).toInt();
         if(prefBitrate==IDX_BITRATE_96k)
@@ -199,25 +197,59 @@ void MainWindow::handleSpotifyLogin()
             selectedBitrate = SP_BITRATE_160k;
 
         m_pSession->init(selectedBitrate); //init new session prior to login
+        m_SessionInit = true;
+    }
 
+    if(m_pConnMan->init()) //init application network session (i.e., make sure that we have an active network connection before proceeding to login)
+    {
+        if(strUserID!="")
+        {//use credentials supplied via login dialog (manual login)
+            err = m_pSession->login(strUserID,strPassword);
+        }
+        else
+        { //use credentials from settings (automatic login)
+            err = m_pSession->login(m_pAppSettings->value("QSpot/UserID").toString(),m_pAppSettings->value("QSpot/Password").toString());
+        }
+        if(err.isError())
+        {
+#ifdef Q_WS_MAEMO_5
+            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+            QMaemo5InformationBox::information(this,tr("Error:") + " " + err.toString());
+#else
+            Banner::information(this,tr("Error:") + " " + err.toString());
+#endif
+            emit showLogin(); //emit signal requesting to show login dialog
+        }
+    }
+    else
+    {
+#ifdef Q_WS_MAEMO_5
+            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide progress indicator
+            QMaemo5InformationBox::information(this,tr("Error:") + " " + tr("No suitable internet access point(s) found!"));
+#else
+            Banner::information(this,tr("Error:") + " " + tr("No suitable internet access point(s) found!");
+#endif
+        emit showLogin(); //emit signal requesting to show login dialog
+    }
+}
+
+void MainWindow::OnHandleLoginType()
+{
+   //Slot for detecting / handling automatic / manual login to Spotify. Performs automatic-login in case user has specified that credentials should be saved;
+   //otherwise the login dialog is displayed so ther user can provide login credentials.
+
+    if(m_pAppSettings->value("QSpot/SaveCredentials",SAVE_CREDENTIALS_DEFAULT).toInt())
+    {
+        //perform automatic login in case user has saved credentials
 #ifdef Q_WS_MAEMO_5
         QMaemo5InformationBox::information(this,tr("Logging in to Spotify"));
 #else
         Banner::information(this,tr("Logging in to Spotify"));
 #endif
-        Spotify::Error err = m_pSession->login(m_pAppSettings->value("QSpot/UserID").toString(),m_pAppSettings->value("QSpot/Password").toString());
-        if(err.isError())
-        {
-            msgBox.setText(tr("Error:") + ":" + err.toString());
-            msgBox.exec();
-            emit showLogin(); //emit signal requesting to show login dialog
-        }
-        else
-        {
 #ifdef Q_WS_MAEMO_5
-            setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
+         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,true); //display progress indicator
 #endif
-        }
+        OnSpotifyLogin("","");
     }
     else
     {
@@ -485,24 +517,29 @@ void MainWindow::OnLoginDialogRejected()
 
 void MainWindow::OnLoggedIn(Spotify::Error error)
 {
-    //Slot invoked when response from login request received
-
-    QString strLoginMsg;
-    QMessageBox msgBox;
+    //Slot invoked when response from login request received (from Spotify service backend)
 
     if(error.isError())
     {
 #ifdef Q_WS_MAEMO_5
         setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false); //hide main window progress indicator
+        QMaemo5InformationBox::information(this,tr("Error:") + error.toString());
+#else
+        Banner::information(this,tr("Error:") + error.toString());
 #endif
-        strLoginMsg = tr("Error:") + error.toString(); //write error string
-        msgBox.setText(strLoginMsg);
-        msgBox.exec();
-        m_pLoginDlg->resetState(); //re-enable login button etc.
-        emit showLogin(); //display login dialog in case auto-login is enabled and has failed
+        if(!m_reConnectReq)
+        {
+            m_pLoginDlg->resetState(); //re-enable login button etc.
+            emit showLogin(); //display login dialog in case auto-login is enabled and has failed
+        }
+        else
+        {
+            m_pReconnectTimer->start(SPOTIFY_RECONNECT_INTERVAL*1000); //start reconnect timer (new attempt to reconnect after SPOTIFY_RECONNECT_INTERVAL secs)
+        }
     }
     else
-    { //successful login to Spotify service, request user playlist / track data (in case initial login request)
+    { //successful login to Spotify service
+        m_pReconnectTimer->stop(); //stop reconnect timer in case it is active
         if(!m_reConnectReq) // do not reload playlist metadata on re-connect request
         {
     #ifdef Q_WS_MAEMO_5
@@ -512,8 +549,7 @@ void MainWindow::OnLoggedIn(Spotify::Error error)
             m_pLoginDlg->hide();
             m_SearchInput.setFocus(); //set default focus to search field
             m_pTimeoutTimer->start(m_pAppSettings->value("QSpot/playlistLoadingTO",PLAYLIST_LOADING_TO_DEFAULT).toInt()*1000); //set timeout value (in msecs)
-           qDebug() << "Got here..";
-            m_pSession->getPlaylistContainer();
+            m_pSession->getPlaylistContainer(); //request user playlist / track data (in case initial login request)
     #ifdef Q_WS_MAEMO_5
             QMaemo5InformationBox::information(this,tr("Loading playlists")); //display loading notification
     #else
@@ -547,8 +583,25 @@ void MainWindow::OnPlaylistLoadingTimeout()
     Banner::information(this,tr("Timeout occured while loading playlists!")); //display timeout notification
 #endif
 
+    setupInitialState(); //setup the app initial state
+}
 
-    setupInitialState();
+void MainWindow::OnReconnectTimeout()
+{
+    //triggered by timer when automatic (timed) reconnect request should be performed (triggered once a minute)
+    Spotify::Error err = m_pSession->reconnect(); //try to re-connect to Spotify using current session credentials
+    if(err.isError())
+    {//some error occured
+#ifdef Q_WS_MAEMO_5
+        QMaemo5InformationBox::information(this,tr("Failed to re-authenticate with Spotify"));
+#else
+        Banner::information(this,tr("Failed to re-authenticate with Spotify"));
+#endif
+    }
+    else
+    {
+        m_pReconnectTimer->stop(); //stop the timer
+    }
 }
 
 void MainWindow::OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists)
@@ -702,6 +755,11 @@ void MainWindow::OnMainMenuAction(QAction* action)
     { //display the FM transmitter control panel dialog (plugin)
         OnDisplayFMTransmitterDialog();
     }
+    else if(action->text()==tr("Online Help"))
+    { //open / display online help content
+        m_pHelpViewer->setContent("http://qspot.garage.maemo.org/qspot_help");
+        m_pHelpViewer->showMaximized();
+    }
     else if(action->text()==tr("About"))
     { //display the app About dialog
         m_AboutDlg.exec();
@@ -913,7 +971,7 @@ void MainWindow::OnLoggedOut()
 #ifdef Q_WS_MAEMO_5
             QMaemo5InformationBox::information(this,tr("Failed to re-authenticate with Spotify"));
 #else
-            Banner::information(this,tr("Failed to re-authenticate with Spotify"));
+            Banner::information(this,tr("Failed to re-authenticate with Spotify."));
 #endif
         }
     }
@@ -924,6 +982,9 @@ void MainWindow::OnSpotifyReconnectRequired()
     //notification that current connection state has changed; reconnection to Spotify backend is required.
 
     qDebug() << "Reconnect req received..";
-    m_reConnectReq = true;
-    m_pSession->logout(); //logout the current user, before initiating new login
+    if(!m_reConnectReq)
+    {
+        m_reConnectReq = true;
+        m_pSession->logout(); //logout the current user, before initiating new login
+    }
 }
