@@ -45,12 +45,12 @@
 #include "DBusWrapper.h"
 #include "ConnectionManager.h"
 #include "global_defs.h"
-#include "Banner.h"
+#include "HelpViewer.h"
 
 
 //defines
 
-#define APP_VERSION "0.9.2-5" //application version string
+#define APP_VERSION "0.9.3-1" //application version string
 
 class MainWindow : public QMainWindow
 {
@@ -75,9 +75,11 @@ private:
 
     QTranslator m_appTranslator;
 
-    LoginDialog* m_pLoginDlg;
+    HelpViewer* m_pHelpViewer; //online help viewer instance
 
-    SettingsDialog* m_pSettingsDlg;
+    LoginDialog* m_pLoginDlg;// login dialog instance
+
+    SettingsDialog* m_pSettingsDlg; //settings dialog instance
 
     TrackView* m_pTrackView; //artist view instance
 
@@ -135,7 +137,11 @@ private:
 
     AboutDialog m_AboutDlg; //App About dialog instance
 
-    QTimer *m_pTimeoutTimer; //timer used for detecting timeouts (i.e., during playlist loading)
+    QTimer *m_pTimeoutTimer; //timer instance used for detecting timeouts (i.e., during playlist loading)
+
+    QTimer *m_pReconnectTimer; //timer instance used for re-connect attempts
+
+    bool m_SessionInit; //TRUE if Spotify session has been initialised (needs to be initialised before loggin in)
 
     bool m_AudioInit; //TRUE in case audio playback thread initialised
 
@@ -155,13 +161,11 @@ private:
 
     void setupUILang(); //setup the UI language
 
-    void handleSpotifyLogin(); //handles the Spotify login process
-
-
 
 private slots:
 
      void OnShowLogin();
+     void OnHandleLoginType(); //slot for detecting / handling automatic / manual login to Spotify
      void OnLoggedIn(Spotify::Error error);
      void OnLoggedOut();
      void OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists);
@@ -178,6 +182,7 @@ private slots:
      void OnPlaybackTokenLost();
      void OnSettingsSaved();
      void OnPlaylistLoadingTimeout();
+     void OnReconnectTimeout();
      void OnDisplayFMTransmitterDialog();
      void OnShowAlbumView(Spotify::Album* pAlbum);
      void OnShowArtistView(Spotify::Artist* pArtist);
@@ -190,10 +195,12 @@ private slots:
      void OnHWZoomKeyPressed(quint32 keycode); //notification that HW zoom key has been pressed
 #endif
      void OnSpotifyReconnectRequired(); //notification that current connection state has changed, and it is required to reconnect to the Spotify backend
+     void OnSpotifyLogin(const QString& strUserID, const QString& strPassword); //slot for handling login to the Spotify backend service
 
 signals:
 
      void showLogin();
+     void handleLoginType();
 
 };
 
