@@ -56,6 +56,14 @@ namespace Spotify
                 }
             }
 
+            // Set review
+            if(m_review.isEmpty())
+            {
+                const char* charData;
+                charData = sp_albumbrowse_review(m_albumBrowser);
+                m_review = QString::fromUtf8(charData, strlen(charData));
+            }
+
             // Set tracks:
             if( m_tracks.isEmpty() )
             {
