@@ -466,12 +466,22 @@ Spotify::Error Spotify::Session::pauseResumeBuffering()
         }
     }
     // buffering currently paused
-    else if( !m_buffering && m_currentTrack->getTrack() && sp_track_is_loaded( m_currentTrack->getTrack() ) )
-    { //resume buffering
-        error = sp_session_player_play( m_session, true );
-        if( !error.isError() )
+    else if( !m_buffering)
+    {
+        if(m_currentTrack)
         {
-             m_buffering = true;
+            if(m_currentTrack->getTrack())
+            {
+                if(sp_track_is_loaded( m_currentTrack->getTrack()))
+                {
+                    //resume buffering
+                    error = sp_session_player_play( m_session, true );
+                    if( !error.isError() )
+                    {
+                         m_buffering = true;
+                    }
+                }
+            }
         }
     }
     return error;
@@ -531,10 +541,7 @@ void Spotify::Session::getPlaylistContainer()
 Spotify::Error Spotify::Session::getPlaylists()
 {
   //get the playlists
-
  Spotify::Error error;
- QWaitCondition sleep;
- QMutex mutex;
 
  m_ProcessEvents = false;
  m_DisableNotifyThread = true;
@@ -548,23 +555,30 @@ Spotify::Error Spotify::Session::getPlaylists()
    int next_timeout = -1;
 
    while(!sp_playlist_is_loaded(pl))
-    { //process main app event loop while waiting for playlist to load
+   { //process main app event loop while waiting for playlist to load
        if(m_bStopPlaylistLoading)
            break;
        sp_session_process_events(m_session,&next_timeout);
        qApp->processEvents();
-       sleep.wait(&mutex,100); //sleep for 100ms just in case that we would have problem with retrieving the last element in the associated list.
-    }
+   }
 
    if(m_bStopPlaylistLoading)
        break;
+	   
+	Spotify::Playlist* playlist = m_playlistList.at(i);
+	if(playlist)
+	{
+	  qDebug() << "Adding playlist: " << sp_playlist_name(pl);
+	  playlist->load(); //playlist loaded, load metadata
+	}
 
-   if(i>=m_playlistList.size())
+  /* if(i>=m_playlistList.size())
    {
        qDebug() << "Adding playlist: " << sp_playlist_name(pl);
        Spotify::Playlist* playlist = new Spotify::Playlist(pl,this);
        m_playlistList.insert(i,playlist); //we could add the following element to the list elements in case of unsupported commands
    }
+   */
 }
   m_bPlaylistsLoading = false; //indicate that playlist loading done (successfully)
 
@@ -661,6 +675,8 @@ void Spotify::Session::updatePlaylistsMetadataSlot()
 {
     qDebug() << "metadata updated..";
 
+    bool allPlaylistsLoaded = true;
+
     for( int i = 0; i < m_playlistList.count(); ++i )
     {
         Spotify::Playlist* playlist = m_playlistList.at(i);
@@ -668,9 +684,20 @@ void Spotify::Session::updatePlaylistsMetadataSlot()
         {
             playlist->load();
             playlist->updateTracks();
+            if(!playlist->isLoaded())
+            {
+                allPlaylistsLoaded = false;
+            }
+            else
+            {
+                qDebug() << "Loaded playlist: " << playlist->getName();
+            }
         }
     }
 
+    if(allPlaylistsLoaded)
+        emit playlistContainersReady(m_playlistList);
+
     // Try to load searches:
     QList<Spotify::Search*> searches = m_searchHash.values();
     for( int i = 0; i < searches.count(); ++i )
@@ -952,13 +979,21 @@ void Spotify::Session::OnRootListContainerLoaded(sp_playlistcontainer* pc)
      m_playlistcontainer = pc;
 
      m_playlistList.clear(); //clear list of playlists
+	 
+	 //add initially empty playlist container instances
+	 for(qint32 pos = 0; pos < sp_playlistcontainer_num_playlists( pc ); pos++)
+	 {
+		 Spotify::Playlist* playlist = new Spotify::Playlist(sp_playlistcontainer_playlist(pc, pos), this);
+		 m_playlistList.insert(pos, playlist); //insert container instance into list
+	 }
 
-     getPlaylists();
+         //playlist metadata will be loaded one we receive corresponding metadata updated callbacks from backend
 
+     //getPlaylists(); //retrieve actual playlist container metadata
 }
 
 void Spotify::Session::tracksAddedCallback( sp_playlist* pl, sp_track* const* tracks, int num_tracks,
-                                           int position, void* userdata )
+                                          int position, void* userdata )
 {
     qDebug()<<"Tracks added callback..";
     Spotify::Session::callingSession->tracksAddedWrapper( pl, tracks, num_tracks, position, userdata );
