@@ -104,6 +104,12 @@ namespace Spotify
              */
             Spotify::Error login( QString username, QString password );
 
+            /**
+             * Reconnects / re-logins current user to Spotify. Used in case network connection etc. is temporarily lost, and reconnect is required.
+             * @return Error
+             */
+            Spotify::Error reconnect();
+
             /**
              * Load a track
              */
@@ -488,7 +494,7 @@ namespace Spotify
             qint32 m_bufferedAmount; //current buffered amount (of the currently loaded track)
             qint64 m_playbackPos; //current playback position for the currently loaded track
 
-            bool m_playing;
+            bool m_buffering; //true in case we are currently buffering
 
             bool m_ProcessEvents;
 
