@@ -63,7 +63,7 @@ bool Spotify::Track::load()
 {
     if( m_track && sp_track_is_loaded( m_track ) && !m_loaded )
     {
-        qDebug()<<"Load track..";
+       // qDebug()<<"Load track..";
         // Set availability:
         m_available = sp_track_is_available( m_track );
 
